@@ -56,7 +56,7 @@ public class Alignment extends Map<String> {
     /**
      * list of data type descriptions, obtained from DataType classes *
      */
-    static TreeMap<String, DataType> types = new TreeMap<>();
+    static TreeMap<String, DataType> types = new TreeMap<>(String.CASE_INSENSITIVE_ORDER);
 
     static {
         findDataTypes();
@@ -86,6 +86,10 @@ public class Alignment extends Map<String> {
         return types.get(name);
     }
 
+    static public TreeMap<String, DataType> getTypes() {
+        return types;
+    }
+
     final public Input<List<Sequence>> sequenceInput =
             new Input<>("sequence", "sequence and meta data for particular taxon", new ArrayList<>(), Validate.OPTIONAL);
 
@@ -272,7 +276,7 @@ public class Alignment extends Map<String> {
             DataType dataType;
             try {
                 dataType = (DataType) BEASTClassLoader.forName(dataTypeName).newInstance();
-                if (dataTypeInput.get().equals(dataType.getTypeDescription())) {
+                if (dataTypeInput.get().equalsIgnoreCase(dataType.getTypeDescription())) {
                     m_dataType = dataType;
                     break;
                 }
@@ -374,6 +378,23 @@ public class Alignment extends Map<String> {
             excludedPatterns = new HashSet<>();
             for (int i = from; i < to; i += every) {
                 int patternIndex_ = patternIndex[i];
+                
+                if (patternWeight[patternIndex_] > 1) {
+                	// when the pattern weight is 2 or larger, perhaps a site that is ascertained for
+                	// accidentally made it into the alignment. Regardless, its contribution to the
+                	// likelihood will be ignored by setting the weight to zero in the line after this
+                	// sanity check, so warn the user about this possibility.
+                	if (to-from == 1) {
+                		int n = patternWeight[patternIndex_] - 1;
+                		Log.warning("WARNING: found " + (n==1?"a site": n+ " sites") + " in the alignment (" + getID() + ") "
+                			+ "that are equal to the ascertainment site. These sites will be ignored in the likelihood "
+                			+ "calculation.");
+                	} else {
+                    	Log.warning("WARNING: found multiple entries for a site that occurs multiple times and is ascertained "
+                    		+ "for. This may indicate some sites should be removed. Regardless, these sites will be ignored in "
+                    		+ "the likelihood calculation.");
+                	}
+                }
                 // reduce weight, so it does not confuse the tree likelihood
                 patternWeight[patternIndex_] = 0;
                 excludedPatterns.add(patternIndex_);
